<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Errore dell&apos;espressione</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark Theme</source>
        <translation>Tema scuro</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Modalità semplice</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Modalità scientifica</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Deepin Calculator</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Deepin Calculator è una calcolatrice semplice e facile da usare. Supporta le somme, le sottrazioni, moltiplicazioni e divisioni.
Localizzazione italiana a cura di Massimo A. Carofano. </translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Errore dell&apos;espressione</translation>
    </message>
</context>
</TS>